<?php

$block_name = _("Latest News");

/**
 * This class extends Horde_Block:: to provide the api to embed news
 * in other Horde applications.
 *
 * $Horde: jonah/lib/Block/latest.php,v 1.10 2006/03/27 19:43:50 chuck Exp $
 *
 * Copyright 2002-2006 Roel Gloudemans <roel@gloudemans.info>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 *
 * @author  Roel Gloudemans <roel@gloudemans.info>
 * @package Horde_Block
 */
class Horde_Block_Jonah_latest extends Horde_Block {

    var $_app = 'jonah';

    /**
     */
    function Horde_Block_Jonah_latest($params = array())
    {
        parent::Horde_Block($params);

        @define('JONAH_BASE', dirname(__FILE__) . '/../..');
        require_once JONAH_BASE . '/lib/Jonah.php';
        require_once JONAH_BASE . '/lib/News.php';
    }

    /**
     */
    function _params()
    {
        global $conf;

        require JONAH_BASE . '/config/conf.php';

        $params['source'] = array('name' => _("News Source"),
                                  'type' => 'enum',
                                  'values' => array());

        $news = &Jonah_News::singleton();
        $channels = $news->getChannels(JONAH_INTERNAL_CHANNEL);
        foreach ($channels as $channel) {
            $params['source']['values'][$channel['channel_id']] = $channel['channel_name'];
        }
        natcasesort($params['source']['values']);

        return $params;
    }

    /**
     */
    function _title()
    {
        if (empty($this->_params['source'])) {
            return _("Latest News");
        }

        $story = $this->_fetch();
        return is_a($story, 'PEAR_Error') ?
            $story->getMessage() :
            '<span class="story_date">' . htmlspecialchars($story['story_published_date']) . '</span> ' . htmlspecialchars($story['story_title']);
    }

    /**
     */
    function _content()
    {
        if (empty($this->_params['source'])) {
            return _("No channel specified.");
        }

        $story = $this->_fetch();
        if (is_a($story, 'PEAR_Error')) {
            return sprintf(_("Error fetching story: %s"), $this->_story->getMessage());
        }

        if (empty($story['story_body_type']) || $story['story_body_type'] == 'text') {
            require_once 'Horde/Text/Filter.php';
            $story['story_body'] = Text_Filter::filter($story['story_body'], 'text2html', array('parselevel' => TEXT_HTML_MICRO, 'class' => null));
        }

        return '<p class="story_subtitle">' . htmlspecialchars($story['story_desc']) .
            '</p><div class="story_body">' . $story['story_body'] . '</div>';
    }

    /**
     * Get the latest story.
     */
    function _fetch()
    {
        if (empty($this->_params['source'])) {
            return;
        }

        $news = &Jonah_News::singleton();
        return $news->getStory($this->_params['source'],
                               $news->getLatestStoryId($this->_params['source']));
    }

}
