<?php
/**
 * $Horde: jonah/stories/view.php,v 1.30 2006/03/27 19:43:50 chuck Exp $
 *
 * Copyright 2003-2006 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 */

$session_control = 'readonly';
@define('AUTH_HANDLER', true);
@define('JONAH_BASE', dirname(__FILE__) . '/..');
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';

$news = &Jonah_News::singleton();

$channel_id = Util::getFormData('channel_id');
$story_id = Util::getFormData('story_id');
if (!$story_id) {
   $story_id = $news->getLatestStoryId($channel_id);
}

$story = $news->getStory($channel_id, $story_id, !$browser->isRobot());
if (is_a($story, 'PEAR_Error')) {
    $notification->push(sprintf(_("Error fetching story: %s"), $story->getMessage()), 'horde.warning');
    require JONAH_TEMPLATES . '/common-header.inc';
    $notification->notify(array('listeners' => 'status'));
    require $registry->get('templates', 'horde') . '/common-footer.inc';
    exit;
} elseif (empty($story['story_body']) && !empty($story['story_url'])) {
    header('Location: ' . Horde::externalUrl($story['story_url']));
    exit;
}

/* Filter and prepare story content. */
$story['story_title'] = htmlspecialchars($story['story_title']);
$story['story_desc'] = htmlspecialchars($story['story_desc']);
if (!empty($story['story_body_type']) && $story['story_body_type'] == 'text') {
    require_once 'Horde/Text/Filter.php';
    $story['story_body'] = Text_Filter::filter($story['story_body'], 'text2html', array('parselevel' => TEXT_HTML_MICRO, 'class' => null));
}

$template = new Horde_Template();
$template->set('story', $story, true);

/* Insert link for sharing. */
if ($conf['sharing']['allow']) {
    $url = Horde::applicationUrl('stories/share.php');
    $url = Util::addParameter($url, array('story_id' => $story['story_id'], 'channel_id' => $channel_id));
    $template->set('sharelink', Horde::link($url, '', 'story_share') . _("Send to a friend") . '</a>', true);
} else {
    $template->set('sharelink', false, true);
}

/* Insert comments. */
if ($conf['comments']['allow']) {
    if (!$registry->hasMethod('forums/renderThreads')
        || !$registry->hasMethod('forums/postMessage')) {
        $err = 'User comments are enabled but the forums API is not available.';
        Horde::logMessage($err, __FILE__, __LINE__, PEAR_LOG_ERR);
    } else {
        $params = array('title' => _("Add a comment"));
        if ($parent = Util::getFormData('parent')) {
            $params['message_parent_id'] = $parent;
        }
        $comments = $registry->call('forums/postMessage', array('jonah', $story_id, 'commentCallback', $params));
        $threads = $registry->call('forums/renderThreads', array($story_id, true, 'jonah', str_replace('%25', '%', Util::addParameter(Horde::selfUrl(true), 'parent', '%p'))));
        if (is_a($threads, 'PEAR_Error')) {
            Horde::logMessage($threads, __FILE__, __LINE__, PEAR_LOG_ERR);
            $threads = '';
        }
        if (is_a($comments, 'PEAR_Error')) {
            Horde::logMessage($threads, __FILE__, __LINE__, PEAR_LOG_ERR);
            $comments = '';
        }
        $comments = $threads . '<br />' . $comments;
        $template->set('comments', $comments, true);
    }
} else {
    $template->set('comments', false, true);
}

$template->set('menu', Jonah::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));
require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/stories/view.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
